nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Activefsm

Enum Activefsm 

#[repr(u8)]
pub enum Activefsm { ACTIVEFSM_0 = 0, ACTIVEFSM_1 = 1, }

Variants



ACTIVEFSM_0 = 0

All PMC finite state machines are idle. OK to set APPLYCFG to trigger the PMC state machines.



ACTIVEFSM_1 = 1

One or more PMC finite state machines are active, do not set APPLYCFG or write to any PDRUNCFG or CTRL register values that are used by the PMC state machines.

Implementations

Source

impl Activefsm

pub const fn from_bits(val: u8) -> Activefsm

pub const fn to_bits(self) -> u8