#[repr(u8)]pub enum Autowkf {
AUTOWKF_0 = 0,
AUTOWKF_1 = 1,
}Variants
AUTOWKF_0 = 0
No PMC Auto Wakeup Interrupt detected since last time cleared.
AUTOWKF_1 = 1
PMC Auto wakeup caused a deep sleep wakeup and interrupt. Write 1 to clear.
Implementations