#[repr(u8)]pub enum Deeppdf {
DEEPPDF_0 = 0,
DEEPPDF_1 = 1,
}Variants
DEEPPDF_0 = 0
No deep powerdown wakeup since last time flag was cleared.
DEEPPDF_1 = 1
Deep powerdown was entered since the last time this flag was cleared. Write 1 to clear
Implementations