#[repr(u8)]pub enum Hvd1v8f {
HVD1V8F_0 = 0,
HVD1V8F_1 = 1,
}Variants
HVD1V8F_0 = 0
vdd1v8 HVD has not triggered an interrupt or reset since last clear
HVD1V8F_1 = 1
vdd1v8 HVD triggered an interrupt or reset since last time this bit was cleared. Write 1 to clear
Implementations