#[repr(u8)]pub enum Lvdcoref {
LVDCOREF_0 = 0,
LVDCOREF_1 = 1,
}Variants
LVDCOREF_0 = 0
vddcore LVD has not triggered an interrupt or reset since last clear
LVDCOREF_1 = 1
vddcore LVD triggered an interrupt or reset since last time this bit was cleared. Write 1 to clear
Implementations