#[repr(u8)]pub enum Resetnpadf {
RESETNPADF_0 = 0,
RESETNPADF_1 = 1,
}Variants
RESETNPADF_0 = 0
No reset detected since last time this flag was cleared.
RESETNPADF_1 = 1
Reset pad wakeup caused a wakeup or reset event since the last time this bit was cleared. Write 1 to clear.
Implementations
Sourceimpl Resetnpadf
impl Resetnpadf